<?php

if (!defined('_PS_VERSION_')) {
    exit;
}

include _PS_MODULE_DIR_ . "netgsmsms/libs/SmsService.php";

class netgsmsms extends Module
{
    public function __construct()
    {
        $this->name = 'netgsmsms';
        $this->tab = 'front_office_features';
        $this->version = '1.0.6';
        $this->author = 'Netgsm';
        $this->need_instance = 1;
        $this->ps_versions_compliancy = array(
            'min' => '1.6',
            'max' => _PS_VERSION_
        );
        $this->bootstrap = true;

        parent::__construct();

        $this->displayName = $this->l('Netgsm Sms');
        $this->description = $this->l('Sending Bulk and Automated Sms');

        $this->confirmUninstall = $this->l('Are you sure you want to uninstall Netgsm Sms?');
        $this->menu_controller = 'AdminNetgsm';
        $this->menu_name = 'Netgsm Sms';


        if (!$this->isRegisteredInHook('actionObjectOrderReturnUpdateAfter'))
            $this->registerHook('actionObjectOrderReturnUpdateAfter');
        if (!$this->isRegisteredInHook('actionOrderReturn'))
            $this->registerHook('actionOrderReturn');
        if (!$this->isRegisteredInHook('actionCustomerAccountAdd'))
            $this->registerHook('actionCustomerAccountAdd');

    }

    public function install()
    {
        if (Shop::isFeatureActive()) {
            Shop::setContext(Shop::CONTEXT_ALL);
        }

        if (!parent::install() ||
            !$this->registerHook('actionOrderStatusPostUpdate') ||
            !$this->registerHook('actionObjectOrderReturnUpdateAfter') ||
            !$this->registerHook('actionOrderReturn') ||
            !$this->registerHook('actionCustomerAccountAdd') ||
            !$this->registerHook('actionObjectAddAfter')) {
            return false;
        }
        include(dirname(__FILE__) . '/sql/install.php');

        if (!$this->installModuleTab($this->menu_controller, 'AdminParentModulesSf')) {
            return false;
        }

        return true;
    }

    public function installModuleTab($tabClassName, $TabParentName)
    {
        $tab = new Tab();
        $tabName = array();
        $langues = Language::getLanguages(false);
        foreach ($langues as $langue) {
            $tabName[$langue['id_lang']] = $this->menu_name;
        }
        $tab_parent_id = self::getIdTab($TabParentName);
        $tab->name = $tabName;
        $tab->class_name = $tabClassName;
        $tab->module = $this->name;
        $tab->id_parent = $tab_parent_id;
        $id_tab = $tab->save();
        if (!$id_tab) {
            return false;
        }
        return true;
    }

    protected static function getIdTab($tabClassName)
    {
        return (int)\Db::getInstance()->getValue(
            'SELECT id_tab FROM ' . _DB_PREFIX_ . 'tab WHERE class_name = \'' . pSQL($tabClassName) . '\''
        );
    }

    public function uninstall()
    {
        include(dirname(__FILE__) . '/sql/uninstall.php');

        $this->unregisterHook('actionOrderStatusPostUpdate');
        $this->unregisterHook('actionObjectAddAfter');
        $this->unregisterHook('actionOrderReturn');
        $this->unregisterHook('actionObjectOrderReturnUpdateAfter');
        $this->unregisterHook('actionCustomerAccountAdd');


        Configuration::deleteByName('netgsmsms');
        Configuration::deleteByName('usercode');
        Configuration::deleteByName('password');
        Configuration::deleteByName('customer_phone_field_name');
        Configuration::deleteByName('title0');
        Configuration::deleteByName('title1');
        Configuration::deleteByName('title2');
        Configuration::deleteByName('groupName');

        $id_tab = self::getIdTab($this->menu_controller);
        if ($id_tab != 0) {
            $tab = new \Tab($id_tab);
            $tab->delete();
        }

        return parent::uninstall();
    }

    public function getContent()
    {
        $output = null;
        $output .= $this->addCss();

        if (Tools::isSubmit('submit' . $this->name)) {

            $usercode = (string)(Tools::getValue('usercode'));
            $password = (string)(Tools::getValue('password'));
            $customer_phone_field_name = (string)(Tools::getValue('customer_phone_field_name'));

            $gonderilecek_mesaj_bilgisi_turu = trim(Tools::getValue('gonderilecek_mesaj_bilgisi_turu'));

            $password = empty($password) ? Configuration::get('password') : $password;

            Configuration::updateValue('gonderilecek_mesaj_bilgisi_turu', $gonderilecek_mesaj_bilgisi_turu);

            if (
                !$usercode || !$password ||
                empty($usercode) || empty($password) ||
                !Validate::isGenericName($usercode) || !Validate::isGenericName($password)
            ) {
                Configuration::deleteByName('title0');
                Configuration::deleteByName('title1');
                Configuration::deleteByName('title2');
                $output .= $this->displayError($this->l('Invalid Configuration Values'));
            } else {

                Configuration::updateValue('usercode', trim($usercode));
                Configuration::updateValue('customer_phone_field_name', trim($customer_phone_field_name));
                Configuration::updateValue('gonderilecek_mesaj_bilgisi_turu', $gonderilecek_mesaj_bilgisi_turu);

                if (trim($password) != '') {
                    Configuration::updateValue('password', trim($password));
                    $titles = SmsService::getTitleAsArray($usercode, $password);
                }

                if (!is_array($titles)) {
                    Configuration::deleteByName('title0');
                    Configuration::deleteByName('title1');
                    Configuration::deleteByName('title2');
                    $output .= $this->displayError($this->l('Invalid Configuration Values'));
                } else {
                    for ($i = 0; $i < count($titles) - 1; $i++) {
                        Configuration::updateValue('title' . $i, $titles[$i]);
                    }
                    $output .= $this->displayConfirmation($this->l('Settings updated'));
                }
            }

            $customer_phone_field_name = Tools::getValue('customer_phone_field_name');

        }
        if (Tools::isSubmit('saveTemplate')) {
            $templateTitle = Tools::getValue('title');
            $templateStatus = Tools::getValue('templateStatus');
            $templateMessage = Tools::getValue('templateMessageArea');
            $templateId = Tools::getValue('templateId');
            $admingsm = Tools::getValue('admingsm');

            $result = $this->saveTemplate($templateId, $templateTitle, $templateStatus, $templateMessage, $admingsm);
            if ($result === true) {
                $output .= $this->displayConfirmation($this->l('Template updated'));
            } else {
                $output .= $this->displayError($this->l("Saving Template Failed."));
            }

        }

        $output .= $this->getTemplatesForm();
        return $output;
    }

    public function saveTemplate($templateId, $templateTitle, $templateStatus, $templateMessage, $admingsm)
    {
        $sql = "UPDATE `" . _DB_PREFIX_ . "netgsmsms_templates` SET `admingsm`='" . $admingsm . "', `template`='" . $templateMessage . "',`title`='" .
            $templateTitle . "',`active`='" . $templateStatus . "'  WHERE `id` = '" . $templateId . "';";
        $result = DB::getInstance()->execute($sql);
        return $result;
    }

    public function isLogin()
    {
        return Configuration::get('title0') ? 1 : 0;
    }

    public function displayForm()
    {
        global $cookie;
        $l = new Language((int)$cookie->id_lang);
        $defaultLang = $l->iso_code;
        $fieldsForm = array();
        // Init Fields form array
        $fieldsForm[0]['form'] = array(
            'legend' => array(
                'title' => $this->l('SETTINGS - ENTER YOUR NETGSM ACCOUNT LOGIN INFORMATION - TITLE WILL AUTOMATICALLY BE FILLED . '),
            ),
            'input' => array(
                array(
                    'type' => 'text',
                    'label' => $this->l('Account No:'),
                    'name' => 'usercode',
                    'size' => 20,
                    'required' => true
                ),
                array(
                    'type' => 'password',
                    'label' => $this->l('Password'),
                    'name' => 'password',
                    'size' => 20,
                    'required' => true
                ),
                array(
                    'type' => 'text',
                    'label' => $this->l('Cep telefonu alanının adı'),
                    'name' => 'customer_phone_field_name',
                    'size' => 100,
                    'required' => false
                ),
                array(
                    'type' => 'text',
                    'label' => $this->l('Message Title 1'),
                    'name' => 'title0',
                    'size' => 20,
                    'disabled' => true
                ),
                array(
                    'type' => 'text',
                    'label' => $this->l('Message Title 2'),
                    'name' => 'title1',
                    'size' => 20,
                    'disabled' => true
                ),
                array(
                    'type' => 'text',
                    'label' => $this->l('Message Title 3'),
                    'name' => 'title2',
                    'size' => 20,
                    'disabled' => true
                ),
                array(
                    'type' => 'select',
                    'label' => 'Gönderilecek Mesaj Türü',
                    'name' => 'gonderilecek_mesaj_bilgisi_turu',
                    'required' => true,
                    'options' => array(
                        'query' => array(
                            array(
                                'id_feature' => 1,
                                'name' => 'Kullanıcı Bilgisi'
                            ),
                            array(
                                'id_feature' => 2,
                                'name' => 'Adres Bilgisi'
                            )),
                        'id' => 'id_feature',
                        'name' => 'name'
                    ),

                ),

            ),
            'submit' => array(
                'title' => $this->l('Save Settings'),
                'class' => 'btn pull-right btn-success'
            )
        );

        $helper = new HelperForm();

        // Module, token and currentIndex
        $helper->module = $this;
        $helper->name_controller = $this->name;
        $helper->token = Tools::getAdminTokenLite('AdminModules');
        $helper->currentIndex = AdminController::$currentIndex . '&configure=' . $this->name;

        // Language
        $helper->default_form_language = $defaultLang;
        $helper->allow_employee_form_lang = $defaultLang;

        // Title and toolbar
        $helper->title = $this->displayName;
        $helper->show_toolbar = true;
        $helper->toolbar_scroll = true;
        $helper->submit_action = 'submit' . $this->name;
        $helper->toolbar_btn = array(
            'save' => array(
                'desc' => $this->l('Save'),
                'href' => AdminController::$currentIndex . '&configure=' . $this->name . '&save' . $this->name .
                    '&token=' . Tools::getAdminTokenLite('AdminModules'),
            ),
            'back' => array(
                'href' => AdminController::$currentIndex . '&token=' . Tools::getAdminTokenLite('AdminModules'),
                'desc' => $this->l('Back to list')
            )
        );

        // Load current value
        $helper->fields_value['usercode'] = Configuration::get('usercode');
        $helper->fields_value['password'] = Configuration::get('password');
        $helper->fields_value['customer_phone_field_name'] = Configuration::get('customer_phone_field_name');
        $helper->fields_value['gonderilecek_mesaj_bilgisi_turu'] = Configuration::get('gonderilecek_mesaj_bilgisi_turu');
        $helper->fields_value['title0'] = Configuration::get('title0');
        $helper->fields_value['title2'] = Configuration::get('title2');
        $helper->fields_value['title1'] = Configuration::get('title1');

        return $helper->generateForm($fieldsForm);
    }

    public function getTemplatesForm()
    {
        $this->context->smarty->assign('isLogin', $this->isLogin());
        $this->context->smarty->assign('configurationTab', $this->displayForm());
        $this->context->smarty->assign('templateTable', $this->getTemplatesTable());
        $this->context->smarty->assign('form_url', Tools::safeOutput($_SERVER['REQUEST_URI']));
        $this->context->smarty->assign('titles', array(Configuration::get('title0'), Configuration::get('title1'), Configuration::get('title2')));
        $this->context->smarty->assign('is_new_version_exist', $this->checkUpgrade());

        return $this->display(__FILE__, 'views/templates/admin/templates.tpl');

    }

    public function checkUpgrade()
    {
        $module = Module::getInstanceByName('netgsmsms');
        $current_version = $module->version;
        $version = file_get_contents("http://api.netgsm.com.tr/plugins/prestashop/version.txt");
//        $version = "1.0.2";
        return $current_version !== $version ? 0 : 1;
    }

    public function getSMSTitles()
    {
        $output = '';
        $output .= '<select id="title" name="title" required class="form-control" style="max-width:50%;">
					        <option value="' . Configuration::get('title0') . '">' . Configuration::get('title0') . '</option>
					        <option value="' . Configuration::get('title1') . '">' . Configuration::get('title1') . '</option>
					        <option value="' . Configuration::get('title2') . '">' . Configuration::get('title2') . '</option>
					   </select>';
        return $output;
    }

    public function getTemplatesTable()
    {
        return $this->getTemplatesTableBody();
    }

    public function getTemplatesTableBody()
    {
        $output = array();
        global $cookie;
        $output ['body'] = '<body>';
        $service = new SmsService();
        $stmt = $service->getAllTemplates();
        $l = new Language((int)$cookie->id_lang);
        $lang = $l->iso_code;
        foreach ($stmt as $row) {

            $variables = '';
            $description = '';

            foreach (json_decode($row['variables'], true)[$lang] as $key => $value) {
                $variables .= $key . ':' . $value . ',';
            }
            $description = json_decode($row['description'], true)[$lang];
            $output ['body'] .= '<tr>';
            $output ['body'] .= '<td style="font-size: 13px;">' . $row['id'] . '</td>';
            if ($lang == 'tr')
                $output ['body'] .= '<td style="font-size: 13px;">' . $row['name_tr'] . '</td>';
            else
                $output ['body'] .= '<td style="font-size: 13px;">' . $row['name'] . '</td>';

            $output ['body'] .= '<td style="font-size: 13px;">' . $row['template'] . '</td>';
            $output ['body'] .= '<td style="font-size: 13px;">' . $description . '</td>';
            $output ['body'] .= '<td style="font-size: 13px; display: none;">' . $variables . '</td>';
            if ((int)$row['active'] === 1) {
                $output ['body'] .= '<td><span class="label" style="background-color:#7dc13c;font-size: 15px;">Aktif</span></td>';
            } else {
                $output ['body'] .= '<td><span class="label" style="background-color:#9D5351;font-size: 15px;">Pasif</span></td>';
            }
            $output ['body'] .= '<td style="font-size: 13px; display: none;">' . $row['type'] . '</td>';
            $output ['body'] .= '<td style="font-size: 13px; display: none;">' . $row['admingsm'] . '</td>';
            $output ['body'] .= '<td style="font-size: 13px; display: none;">' . $row['title'] . '</td>';
            $output ['body'] .= '<td><a href="#0" data-toggle="modal" class="btn btn-xs btn-warning" onclick="callModal(this)">
                                <i class="fa fa-edit" style="font-size:18px"></i>
                            </a></td>';
            $output ['body'] .= '</tr>';
        }

        $output ['body'] .= '</body>';

        return $output;
    }

    public function addCss()
    {
        $output = '<link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/4.7.0/css/font-awesome.min.css">';
        return $output;
    }

    /*
     * send message to customer when status of an order changes
     */

    public function hookActionCustomerAccountAdd($params)
    {
        $service = new SmsService();

        $usercode = Configuration::get('usercode');
        $password = Configuration::get('password');
        $customer_phone_field_name = Configuration::get('customer_phone_field_name');

        $customer = $params['newCustomer'];
        $firstname = $customer->firstname;
        $lastname = $customer->lastname;
        $email = $customer->email;
        $date_add = $customer->date_add;
        $customer_phone = $customer->$customer_phone_field_name;
        $phones = array();
        $phones [] = $customer_phone;

        $rows = DB::getInstance()->executeS("SELECT * FROM `" . _DB_PREFIX_ . "netgsmsms_templates` 
                WHERE name = '" . __FUNCTION__ . "';");

        if (empty($rows)) {
            return false;
        }

        foreach ($rows as $row) {

            if ((int)$row['active'] == 0) {
                continue;
            }
            $title = $row['title'];
            if (empty($title)) {
                continue;
            }

            $template = $row ['template'];

            if (trim($row['type']) == "admin") {
                $phones = $row['admingsm'];
                if (strpos($phones, ",") !== false) {
                    $phones = explode(",", $phones);
                }
            }

            foreach ($phones as $phone) {
                if (is_numeric($phone) and mb_strlen(trim($phone)) < 13 and mb_strlen(trim($phone)) > 9) {

                    $tmp_variables = array(
                        '(firstname)' => $firstname,
                        '(lastname)' => $lastname,
                        '(phone)' => $customer_phone,
                        '(email)' => $email,
                        '(date)' => $date_add
                    );

                    $message = $this->parseSmsTemplate($tmp_variables, $template);
                    $service->sendOneSms($phone, $message, $title, $usercode, $password);
                }
            }
        }
    }

    public function hookActionOrderReturn($params)
    {
        $function = "hookActionObjectOrderReturnUpdateAfter";

        $usercode = Configuration::get('usercode');
        $password = Configuration::get('password');
        $gonderilecek_mesaj_bilgisi_turu = Configuration::get('gonderilecek_mesaj_bilgisi_turu');

        $id_customer = $params['orderReturn']->id_customer;
        $customer = new Customer($id_customer);
        $id_order = $params['orderReturn']->id_order;
        $state = $params['orderReturn']->state;
        $state = trim($state);
        $cookie = $params['cookie'];
        $all = $cookie->getAll();
        $id_lang = $all['id_lang'];
        $orderReturnStateText = '';
        $order = new Order($id_order);

        $orderReturnState = OrderReturnState::getOrderReturnStates($id_lang);

        $address = new Address((int)($order->id_address_invoice));
        $customer_phone = $address->phone_mobile;

        $row = DB::getInstance()->getRow("SELECT * FROM `" . _DB_PREFIX_ . "netgsmsms_templates` WHERE name='" . $function . $state . "'");


        if ($row === false) {
            return null;
        }

        if ((int)$row['active'] == 0)
            return null;
        $title = $row['title'];
        if (empty($title))
            return null;
        $template = $row ['template'];

        if (is_array($orderReturnState)) {
            foreach ($orderReturnState as $ReturnState) {
                if ($ReturnState['id_order_return_state'] == $state) {
                    $orderReturnStateText = $ReturnState['name'];
                }
            }
        }

        if ($gonderilecek_mesaj_bilgisi_turu == "1") {
            $firstname = $customer->firstname;
            $lastname = $customer->lastname;
        } else {
            $firstname = $address->firstname;
            $lastname = $address->lastname;
        }

        if (empty($customer_phone))
            $customer_phone = $address->phone;

        if (empty($customer_phone)) {
            return null;
        }
        $tmp_variables = array(
            '(order_id)' => $id_order,
            '(firstname)' => $firstname,
            '(lastname)' => $lastname,
            '(phone)' => $customer_phone,
            '(reference_id)' => $order->reference,
            '(return_state)' => $orderReturnStateText
        );

        $message = $this->parseSmsTemplate($tmp_variables, $template);

        $service = new SmsService();
        $service->sendOneSms($customer_phone, $message, $title, $usercode, $password);
    }

    public function hookActionObjectOrderReturnUpdateAfter($params)
    {
        try {

            $usercode = Configuration::get('usercode');
            $password = Configuration::get('password');
            $gonderilecek_mesaj_bilgisi_turu = Configuration::get('gonderilecek_mesaj_bilgisi_turu');

            $id_customer = $params['object']->id_customer;
            $customer = new Customer($id_customer);
            $id_order = $params['object']->id_order;
            $state = $params['object']->state;
            $state = trim($state);
            $cookie = $params['cookie'];
            $all = $cookie->getAll();
            $id_lang = $all['id_lang'];
            $orderReturnStateText = '';
            $order = new Order($id_order);

            $address = new Address((int)($order->id_address_invoice));
            $customer_phone = $address->phone_mobile;

            $orderReturnState = OrderReturnState::getOrderReturnStates($id_lang);

            $row = DB::getInstance()->getRow("SELECT * FROM `" . _DB_PREFIX_ . "netgsmsms_templates` WHERE name='" . __FUNCTION__ . $state . "'");
            if ($row === false) {
                return null;
            }
            if ((int)$row['active'] == 0)
                return null;
            $title = $row['title'];
            if (empty($title))
                return null;
            $template = $row ['template'];

            if (is_array($orderReturnState)) {
                foreach ($orderReturnState as $ReturnState) {
                    if ($ReturnState['id_order_return_state'] == $state) {
                        $orderReturnStateText = $ReturnState['name'];
                    }
                }
            }


            if ($gonderilecek_mesaj_bilgisi_turu == "1") {
                $firstname = $customer->firstname;
                $lastname = $customer->lastname;
            } else {
                $firstname = $address->firstname;
                $lastname = $address->lastname;
            }


            if (empty($customer_phone))
                $customer_phone = $address->phone;
            if (empty($customer_phone)) {
                return null;
            }

            $tmp_variables = array(
                '(order_id)' => $id_order,
                '(firstname)' => $firstname,
                '(lastname)' => $lastname,
                '(phone)' => $customer_phone,
                '(reference_id)' => $order->reference,
                '(return_state)' => $orderReturnStateText
            );

            $message = $this->parseSmsTemplate($tmp_variables, $template);

            $service = new SmsService();
            $service->sendOneSms($customer_phone, $message, $title, $usercode, $password);

        } catch (Exception $e) {

        }

    }

    public function hookActionOrderStatusPostUpdate($params)
    {
        try {
            $usercode = Configuration::get('usercode');
            $password = Configuration::get('password');
            $gonderilecek_mesaj_bilgisi_turu = Configuration::get('gonderilecek_mesaj_bilgisi_turu');

            $service = new SmsService();
            $orderStatus = $params['newOrderStatus'];
            $order = new Order($params['id_order']);
            $tracking_id = $order->getShipping()[0]['tracking_number'];
            $customer = new Customer($order->id_customer);
            $address = new Address((int)($order->id_address_invoice));
            $customer_phone = $address->phone_mobile;
            $carrier_name = '';

//            print_r($params);


//            $sql = "INSERT INTO `a_log`(`log`) VALUES ('aaaaaaaaaaaa')";
//            $row = DB::getInstance()->executeS($sql);
//
//            $sql = "INSERT INTO `a_log`(`log`) VALUES ('".$address->phone."')";
//            $row = DB::getInstance()->executeS($sql);
//            $sql = "INSERT INTO `a_log`(`log`) VALUES ('".json_encode($address)."')";
//            $row = DB::getInstance()->executeS($sql);
//
//            print_r($address);

            if ($gonderilecek_mesaj_bilgisi_turu == "1") {
                $firstname = $customer->firstname;
                $lastname = $customer->lastname;
            } else {
                $firstname = $address->firstname;
                $lastname = $address->lastname;
            }


            if (empty($customer_phone))
                $customer_phone = $address->phone;
            if (empty($customer_phone))
                return null;


            if (!empty($tracking_id)) {
                $sql = "select pc.name from " . _DB_PREFIX_ . "order_carrier as poc
                    inner join " . _DB_PREFIX_ . "carrier as pc on poc.id_carrier = pc.id_carrier and pc.deleted=0 and pc.active=1
                    where poc.tracking_number='" . $tracking_id . "'";
                $row = DB::getInstance()->getRow($sql);
                $carrier_name = $row['name'];
            }
            $tmp_variables = array(
                '(order_id)' => $params['id_order'],
                '(firstname)' => $firstname,
                '(lastname)' => $lastname,
                '(phone)' => $customer_phone,
                '(reference_id)' => $order->reference,
                '(order_status)' => $orderStatus->name,
                '(tracking_id)' => $tracking_id,
                '(carrier_name)' => $carrier_name
            );

            $customer_phone = preg_replace("/[^0-9]/", "", $customer_phone);
            $validphone = $this->checkPhoneNumber($customer_phone);

            if ($validphone === false)
                return null;

            if (empty($usercode) || empty($password))
                return null;

            $row = DB::getInstance()->getRow("SELECT * FROM `" . _DB_PREFIX_ . "netgsmsms_templates` WHERE name='" . __FUNCTION__ . $orderStatus->id . "'");
            if ($row === false) {
                return null;
            }
            if ((int)$row['active'] == 0)
                return null;
            $title = $row['title'];
            if (empty($title))
                return null;
            $template = $row ['template'];

            $message = $this->parseSmsTemplate($tmp_variables, $template);

            $service->sendOneSms($customer_phone, $message, $title, $usercode, $password);

        } catch (PrestaShopDatabaseException $e) {

        } catch (PrestaShopException $e) {

        }

    }

    /*
     * send message to admin when an order confirmed
     */
    public function hookActionObjectAddAfter($params)
    {
        $usercode = Configuration::get('usercode');
        $password = Configuration::get('password');


        try {
            if (get_class($params['object']) == 'Order') {

                $service = new SmsService();
                $order = $params['object'];
                $total_paid = $order->total_paid;
                $order_id = $order->id;
                $reference_id = $order->reference;
                $tmp_variables = array(
                    '(order_id)' => $order_id,
                    '(reference_id)' => $reference_id,
                    '(total)' => $total_paid,
                );

                if (empty($usercode) || empty($password))
                    return null;

                $row = DB::getInstance()->getRow("SELECT * FROM `" . _DB_PREFIX_ . "netgsmsms_templates` 
                WHERE name = '" . __FUNCTION__ . get_class($params['object']) . "';");

                if (!$row || (int)$row['active'] == 0 || empty($row['title']))
                    return null;
                $title = $row['title'];
                $template = $row['template'];

                $admingsms = explode(",", $row['admingsm']);
                $newadmingsms = array();

                foreach ($admingsms as $key => $value) {
                    $value = preg_replace("/[^0-9]/", "", $value);
                    $validphone = $this->checkPhoneNumber($value);
                    if ($validphone)
                        $newadmingsms [] = $value;
                }

                $message = $this->parseSmsTemplate($tmp_variables, $template);
                foreach ($newadmingsms as $key => $value)
                    $service->sendOneSms($value, $message, $title, $usercode, $password);

            }

            if (get_class($params['object']) == "CustomerMessage") {

                $customerMessage = $params['object'];
                /*
                 * When Admin Sends Message to the customer
                 */
                if ($customerMessage->id_employee > 0 && $customerMessage->private == 0) {

                    $ct = new CustomerThread($customerMessage->id_customer_thread);

                    if ((int)$ct->id_order < 1) {

                        $customer_phone = "0";
                    } else {
                        $order = new Order($ct->id_order);
                        $customer = new Customer($ct->id_customer);
                        $address = new Address((int)($order->id_address_invoice));
                        $customer_phone = $address->phone_mobile;
                    }

                    if (empty($customer_phone))
                        $customer_phone = $address->phone;

                    $customer_phone = preg_replace("/[^0-9]/", "", $customer_phone);
                    $validphone = $this->checkPhoneNumber($customer_phone);
                    if (!$validphone) {
                        return null;
                    }

                    $service = new SmsService();
                    $order_id = $order->id;
                    $reference_id = $order->reference;
                    $tmp_variables = array(
                        '(firstname)' => $customer->firstname,
                        '(lastname)' => $customer->lastname,
                        '(order_id)' => $order_id,
                        '(reference_id)' => $reference_id,
                    );

                    $row = DB::getInstance()->getRow("SELECT * FROM `" . _DB_PREFIX_ . "netgsmsms_templates`
                    WHERE name = '" . __FUNCTION__ . get_class($params['object']) . "Admin';");

                    if (!$row || (int)$row['active'] == 0 || empty($row['title']))
                        return null;
                    $title = $row['title'];
                    $template = $row['template'];

                    $message = $this->parseSmsTemplate($tmp_variables, $template);
                    $service->sendOneSms($customer_phone, $message, $title, $usercode, $password);

                } /*
                 * When Customer Sends Message to the admin
                 */
                else {

                    $ct = new CustomerThread($customerMessage->id_customer_thread);
                    $order = new Order($ct->id_order);
                    $customer_id = $ct->id_customer;
                    $address = new Address((int)($order->id_address_invoice));
                    $message = $customerMessage->message;
                    $service = new SmsService();

                    $tmp_variables = array(
                        '(customer_id)' => $customer_id,
                        '(order_id)' => $ct->id_order,
                        '(message)' => $message,
                    );

                    $row = DB::getInstance()->getRow("SELECT * FROM `" . _DB_PREFIX_ . "netgsmsms_templates` 
                    WHERE name = '" . __FUNCTION__ . get_class($params['object']) . "Customer';");


                    if (!$row || (int)$row['active'] == 0 || empty($row['title']))
                        return null;

                    $title = $row['title'];
                    $template = $row['template'];
                    $admingsms = explode(",", $row['admingsm']);
                    $newadmingsms = array();

                    foreach ($admingsms as $key => $value) {
                        $value = preg_replace("/[^0-9]/", "", $value);
                        $validphone = $this->checkPhoneNumber($value);
                        if ($validphone)
                            $newadmingsms [] = $value;
                    }

                    $message = $this->parseSmsTemplate($tmp_variables, $template);

                    foreach ($newadmingsms as $key => $value)
                        $service->sendOneSms($value, $message, $title, $usercode, $password);
                }
            }
        } catch (Exception $e) {

        }

    }

    public function parseSmsTemplate($tmp_variables, $template)
    {
        return str_replace(array_keys($tmp_variables), array_values($tmp_variables), $template);
    }

    public function checkPhoneNumber($gsm)
    {
        if ($gsm{0} === "+") {
            $gsm = Tools::substr($gsm, 3);
            $gsm = str_replace(" ", "", $gsm);
        }
        if (!ctype_digit($gsm)) {
            return false;
        }
        if ($gsm{0} !== "0" && Tools::strlen($gsm) == 11) {
            return false;
        }
        if ($gsm{0} !== "5" && Tools::strlen($gsm) == 10) {
            return false;
        }
        if ($gsm{0} !== "9" && Tools::strlen($gsm) == 12) {
            return false;
        }

        return true;
    }
}
